summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--examples/simple_tcp_server.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/simple_tcp_server.py b/examples/simple_tcp_server.py
index b796d9b..5f874ff 100644
--- a/examples/simple_tcp_server.py
+++ b/examples/simple_tcp_server.py
@@ -4,7 +4,7 @@ style and uses asyncio.streams.start_server() and
asyncio.streams.open_connection().
Note that running this example starts both the TCP server and client
-in the same process. It listens on port 1234 on 127.0.0.1, so it will
+in the same process. It listens on port 12345 on 127.0.0.1, so it will
fail if this port is currently in use.
"""
@@ -83,7 +83,7 @@ class MyServer:
def start(self, loop):
"""
Starts the TCP server, so that it listens on port 1234.
For each client that connects, the accept_client method gets
called. This method runs the loop until the server sockets
@@ -83,7 +83,7 @@ class MyServer:
def start(self, loop):
"""
- Starts the TCP server, so that it listens on port 1234.
+ Starts the TCP server, so that it listens on port 12345.
For each client that connects, the accept_client method gets
called. This method runs the loop until the server sockets